"""様式コード (formCode) のモデル定義。

AUTO-GENERATED by tools/generate_form_codes.py. DO NOT EDIT.
Source: data/source/ESE140327.xlsx
"""
from __future__ import annotations

import warnings

from pydantic import BaseModel, ConfigDict

from edinet.exceptions import EdinetWarning


class FormCodeEntry(BaseModel):
    """様式コードリストの1行。"""

    model_config = ConfigDict(frozen=True)

    ordinance_code: str
    form_code: str
    form_number: str
    form_name: str
    doc_type_name: str
    disclosure_type: str
    note: str | None = None

    def __str__(self) -> str:
        return f"FormCodeEntry({self.ordinance_code}/{self.form_code} | {self.form_name})"


_FORM_CODE_TABLE: dict[tuple[str, str], FormCodeEntry] = {
    ('010', '010000'): FormCodeEntry(
        ordinance_code='010',
        form_code='010000',
        form_number='第一号様式',
        form_name='有価証券通知書',
        doc_type_name='有価証券通知書',
        disclosure_type='非開示',
        note=None,
    ),
    ('010', '010001'): FormCodeEntry(
        ordinance_code='010',
        form_code='010001',
        form_number='第一号様式',
        form_name='変更有価証券通知書',
        doc_type_name='変更通知書（有価証券通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('010', '020000'): FormCodeEntry(
        ordinance_code='010',
        form_code='020000',
        form_number='第二号様式',
        form_name='有価証券届出書（通常方式）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '020001'): FormCodeEntry(
        ordinance_code='010',
        form_code='020001',
        form_number='第二号様式',
        form_name='訂正有価証券届出書（通常方式）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '022000'): FormCodeEntry(
        ordinance_code='010',
        form_code='022000',
        form_number='第二号の二様式',
        form_name='有価証券届出書（組込方式）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '022001'): FormCodeEntry(
        ordinance_code='010',
        form_code='022001',
        form_number='第二号の二様式',
        form_name='訂正有価証券届出書（組込方式）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '023000'): FormCodeEntry(
        ordinance_code='010',
        form_code='023000',
        form_number='第二号の三様式',
        form_name='有価証券届出書（参照方式）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '023001'): FormCodeEntry(
        ordinance_code='010',
        form_code='023001',
        form_number='第二号の三様式',
        form_name='訂正有価証券届出書（参照方式）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '024000'): FormCodeEntry(
        ordinance_code='010',
        form_code='024000',
        form_number='第二号の四様式',
        form_name='有価証券届出書（新規公開時）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '024001'): FormCodeEntry(
        ordinance_code='010',
        form_code='024001',
        form_number='第二号の四様式',
        form_name='訂正有価証券届出書（新規公開時）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '025000'): FormCodeEntry(
        ordinance_code='010',
        form_code='025000',
        form_number='第二号の五様式',
        form_name='有価証券届出書（少額募集等）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '025001'): FormCodeEntry(
        ordinance_code='010',
        form_code='025001',
        form_number='第二号の五様式',
        form_name='訂正有価証券届出書（少額募集等）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '026000'): FormCodeEntry(
        ordinance_code='010',
        form_code='026000',
        form_number='第二号の六様式',
        form_name='有価証券届出書（組織再編成）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '026001'): FormCodeEntry(
        ordinance_code='010',
        form_code='026001',
        form_number='第二号の六様式',
        form_name='訂正有価証券届出書（組織再編成）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '027000'): FormCodeEntry(
        ordinance_code='010',
        form_code='027000',
        form_number='第二号の七様式',
        form_name='有価証券届出書（組織再編成・上場）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '027001'): FormCodeEntry(
        ordinance_code='010',
        form_code='027001',
        form_number='第二号の七様式',
        form_name='訂正有価証券届出書（組織再編成・上場）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '030000'): FormCodeEntry(
        ordinance_code='010',
        form_code='030000',
        form_number='第三号様式',
        form_name='有価証券報告書',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '030001'): FormCodeEntry(
        ordinance_code='010',
        form_code='030001',
        form_number='第三号様式',
        form_name='訂正有価証券報告書',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '032000'): FormCodeEntry(
        ordinance_code='010',
        form_code='032000',
        form_number='第三号の二様式',
        form_name='有価証券報告書（少額募集等）',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '032001'): FormCodeEntry(
        ordinance_code='010',
        form_code='032001',
        form_number='第三号の二様式',
        form_name='訂正有価証券報告書（少額募集等）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '040000'): FormCodeEntry(
        ordinance_code='010',
        form_code='040000',
        form_number='第四号様式',
        form_name='有価証券報告書（法24条3項に基づくもの）',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '040001'): FormCodeEntry(
        ordinance_code='010',
        form_code='040001',
        form_number='第四号様式',
        form_name='訂正有価証券報告書（法24条3項に基づくもの）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '042000'): FormCodeEntry(
        ordinance_code='010',
        form_code='042000',
        form_number='第四号の二様式',
        form_name='確認書',
        doc_type_name='確認書',
        disclosure_type='開示',
        note='有価証券報告書、半期報告書、四半期報告書に係る確認書',
    ),
    ('010', '042001'): FormCodeEntry(
        ordinance_code='010',
        form_code='042001',
        form_number='第四号の二様式',
        form_name='訂正確認書',
        doc_type_name='訂正確認書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '042100'): FormCodeEntry(
        ordinance_code='010',
        form_code='042100',
        form_number='第四号の二様式',
        form_name='確認書',
        doc_type_name='確認書',
        disclosure_type='開示',
        note='訂正有価証券報告書に係る確認書',
    ),
    ('010', '042200'): FormCodeEntry(
        ordinance_code='010',
        form_code='042200',
        form_number='第四号の二様式',
        form_name='確認書',
        doc_type_name='確認書',
        disclosure_type='開示',
        note='訂正半期報告書に係る確認書',
    ),
    ('010', '042300'): FormCodeEntry(
        ordinance_code='010',
        form_code='042300',
        form_number='第四号の二様式',
        form_name='確認書',
        doc_type_name='確認書',
        disclosure_type='開示',
        note='訂正四半期報告書に係る確認書',
    ),
    ('010', '043000'): FormCodeEntry(
        ordinance_code='010',
        form_code='043000',
        form_number='第四号の三様式',
        form_name='四半期報告書',
        doc_type_name='四半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '043001'): FormCodeEntry(
        ordinance_code='010',
        form_code='043001',
        form_number='第四号の三様式',
        form_name='訂正四半期報告書',
        doc_type_name='訂正四半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '043A00'): FormCodeEntry(
        ordinance_code='010',
        form_code='043A00',
        form_number='第四号の三様式',
        form_name='半期報告書',
        doc_type_name='半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '043A01'): FormCodeEntry(
        ordinance_code='010',
        form_code='043A01',
        form_number='第四号の三様式',
        form_name='訂正半期報告書',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '050000'): FormCodeEntry(
        ordinance_code='010',
        form_code='050000',
        form_number='第五号様式',
        form_name='半期報告書',
        doc_type_name='半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '050001'): FormCodeEntry(
        ordinance_code='010',
        form_code='050001',
        form_number='第五号様式',
        form_name='訂正半期報告書',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '052000'): FormCodeEntry(
        ordinance_code='010',
        form_code='052000',
        form_number='第五号の二様式',
        form_name='半期報告書（少額募集等）',
        doc_type_name='半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '052001'): FormCodeEntry(
        ordinance_code='010',
        form_code='052001',
        form_number='第五号の二様式',
        form_name='訂正半期報告書（少額募集等）',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '053000'): FormCodeEntry(
        ordinance_code='010',
        form_code='053000',
        form_number='第五号の三様式',
        form_name='臨時報告書',
        doc_type_name='臨時報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '053001'): FormCodeEntry(
        ordinance_code='010',
        form_code='053001',
        form_number='第五号の三様式',
        form_name='訂正臨時報告書',
        doc_type_name='訂正臨時報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '054000'): FormCodeEntry(
        ordinance_code='010',
        form_code='054000',
        form_number='第五号の四様式',
        form_name='親会社等状況報告書（内国会社）',
        doc_type_name='親会社等状況報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '054001'): FormCodeEntry(
        ordinance_code='010',
        form_code='054001',
        form_number='第五号の四様式',
        form_name='訂正親会社等状況報告書（内国会社）',
        doc_type_name='訂正親会社等状況報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '060000'): FormCodeEntry(
        ordinance_code='010',
        form_code='060000',
        form_number='第六号様式',
        form_name='有価証券通知書',
        doc_type_name='有価証券通知書',
        disclosure_type='非開示',
        note=None,
    ),
    ('010', '060001'): FormCodeEntry(
        ordinance_code='010',
        form_code='060001',
        form_number='第六号様式',
        form_name='変更有価証券通知書',
        doc_type_name='変更通知書（有価証券通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('010', '070000'): FormCodeEntry(
        ordinance_code='010',
        form_code='070000',
        form_number='第七号様式',
        form_name='有価証券届出書（通常方式）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '070001'): FormCodeEntry(
        ordinance_code='010',
        form_code='070001',
        form_number='第七号様式',
        form_name='訂正有価証券届出書（通常方式）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '072000'): FormCodeEntry(
        ordinance_code='010',
        form_code='072000',
        form_number='第七号の二様式',
        form_name='有価証券届出書（組込方式）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '072001'): FormCodeEntry(
        ordinance_code='010',
        form_code='072001',
        form_number='第七号の二様式',
        form_name='訂正有価証券届出書（組込方式）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '073000'): FormCodeEntry(
        ordinance_code='010',
        form_code='073000',
        form_number='第七号の三様式',
        form_name='有価証券届出書（参照方式）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '073001'): FormCodeEntry(
        ordinance_code='010',
        form_code='073001',
        form_number='第七号の三様式',
        form_name='訂正有価証券届出書（参照方式）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '074000'): FormCodeEntry(
        ordinance_code='010',
        form_code='074000',
        form_number='第七号の四様式',
        form_name='有価証券届出書（組織再編成）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '074001'): FormCodeEntry(
        ordinance_code='010',
        form_code='074001',
        form_number='第七号の四様式',
        form_name='訂正有価証券届出書（組織再編成）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '075000'): FormCodeEntry(
        ordinance_code='010',
        form_code='075000',
        form_number='第七号の五様式',
        form_name='外国会社届出書',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '075001'): FormCodeEntry(
        ordinance_code='010',
        form_code='075001',
        form_number='第七号の五様式',
        form_name='外国会社訂正届出書',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '080000'): FormCodeEntry(
        ordinance_code='010',
        form_code='080000',
        form_number='第八号様式',
        form_name='有価証券報告書',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '080001'): FormCodeEntry(
        ordinance_code='010',
        form_code='080001',
        form_number='第八号様式',
        form_name='訂正有価証券報告書',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '082000'): FormCodeEntry(
        ordinance_code='010',
        form_code='082000',
        form_number='第八号の二様式',
        form_name='外国会社報告書',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '082001'): FormCodeEntry(
        ordinance_code='010',
        form_code='082001',
        form_number='第八号の二様式',
        form_name='外国会社訂正報告書',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '082100'): FormCodeEntry(
        ordinance_code='010',
        form_code='082100',
        form_number='第八号の二様式',
        form_name='外国会社確認書',
        doc_type_name='確認書',
        disclosure_type='開示',
        note='有価証券報告書、半期報告書、四半期報告書に係る確認書',
    ),
    ('010', '082101'): FormCodeEntry(
        ordinance_code='010',
        form_code='082101',
        form_number='第八号の二様式',
        form_name='外国会社訂正確認書',
        doc_type_name='訂正確認書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '082200'): FormCodeEntry(
        ordinance_code='010',
        form_code='082200',
        form_number='第八号の二様式',
        form_name='外国会社四半期報告書',
        doc_type_name='四半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '082201'): FormCodeEntry(
        ordinance_code='010',
        form_code='082201',
        form_number='第八号の二様式',
        form_name='外国会社四半期訂正報告書',
        doc_type_name='訂正四半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '082300'): FormCodeEntry(
        ordinance_code='010',
        form_code='082300',
        form_number='第八号の二様式',
        form_name='外国会社半期報告書',
        doc_type_name='半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '082301'): FormCodeEntry(
        ordinance_code='010',
        form_code='082301',
        form_number='第八号の二様式',
        form_name='外国会社半期訂正報告書',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '082400'): FormCodeEntry(
        ordinance_code='010',
        form_code='082400',
        form_number='第八号の二様式',
        form_name='外国会社確認書',
        doc_type_name='確認書',
        disclosure_type='開示',
        note='訂正有価証券報告書に係る確認書',
    ),
    ('010', '082500'): FormCodeEntry(
        ordinance_code='010',
        form_code='082500',
        form_number='第八号の二様式',
        form_name='外国会社確認書',
        doc_type_name='確認書',
        disclosure_type='開示',
        note='訂正半期報告書に係る確認書',
    ),
    ('010', '082600'): FormCodeEntry(
        ordinance_code='010',
        form_code='082600',
        form_number='第八号の二様式',
        form_name='外国会社確認書',
        doc_type_name='確認書',
        disclosure_type='開示',
        note='訂正四半期報告書に係る確認書',
    ),
    ('010', '090000'): FormCodeEntry(
        ordinance_code='010',
        form_code='090000',
        form_number='第九号様式',
        form_name='有価証券報告書（法24条3項に基づくもの）',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '090001'): FormCodeEntry(
        ordinance_code='010',
        form_code='090001',
        form_number='第九号様式',
        form_name='訂正有価証券報告書（法24条3項に基づくもの）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '092000'): FormCodeEntry(
        ordinance_code='010',
        form_code='092000',
        form_number='第九号の二様式',
        form_name='確認書',
        doc_type_name='確認書',
        disclosure_type='開示',
        note='有価証券報告書、半期報告書、四半期報告書に係る確認書',
    ),
    ('010', '092001'): FormCodeEntry(
        ordinance_code='010',
        form_code='092001',
        form_number='第九号の二様式',
        form_name='訂正確認書',
        doc_type_name='訂正確認書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '092100'): FormCodeEntry(
        ordinance_code='010',
        form_code='092100',
        form_number='第九号の二様式',
        form_name='確認書',
        doc_type_name='確認書',
        disclosure_type='開示',
        note='訂正有価証券報告書に係る確認書',
    ),
    ('010', '092200'): FormCodeEntry(
        ordinance_code='010',
        form_code='092200',
        form_number='第九号の二様式',
        form_name='確認書',
        doc_type_name='確認書',
        disclosure_type='開示',
        note='訂正半期報告書に係る確認書',
    ),
    ('010', '092300'): FormCodeEntry(
        ordinance_code='010',
        form_code='092300',
        form_number='第九号の二様式',
        form_name='確認書',
        doc_type_name='確認書',
        disclosure_type='開示',
        note='訂正四半期報告書に係る確認書',
    ),
    ('010', '093000'): FormCodeEntry(
        ordinance_code='010',
        form_code='093000',
        form_number='第九号の三様式',
        form_name='四半期報告書',
        doc_type_name='四半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '093001'): FormCodeEntry(
        ordinance_code='010',
        form_code='093001',
        form_number='第九号の三様式',
        form_name='訂正四半期報告書',
        doc_type_name='訂正四半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '093A00'): FormCodeEntry(
        ordinance_code='010',
        form_code='093A00',
        form_number='第九号の三様式',
        form_name='半期報告書',
        doc_type_name='半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '093A01'): FormCodeEntry(
        ordinance_code='010',
        form_code='093A01',
        form_number='第九号の三様式',
        form_name='訂正半期報告書',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '100000'): FormCodeEntry(
        ordinance_code='010',
        form_code='100000',
        form_number='第十号様式',
        form_name='半期報告書',
        doc_type_name='半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '100001'): FormCodeEntry(
        ordinance_code='010',
        form_code='100001',
        form_number='第十号様式',
        form_name='訂正半期報告書',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '102000'): FormCodeEntry(
        ordinance_code='010',
        form_code='102000',
        form_number='第十号の二様式',
        form_name='臨時報告書',
        doc_type_name='臨時報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '102001'): FormCodeEntry(
        ordinance_code='010',
        form_code='102001',
        form_number='第十号の二様式',
        form_name='訂正臨時報告書',
        doc_type_name='訂正臨時報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '102100'): FormCodeEntry(
        ordinance_code='010',
        form_code='102100',
        form_number='第十号の二様式',
        form_name='外国会社臨時報告書',
        doc_type_name='臨時報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '102101'): FormCodeEntry(
        ordinance_code='010',
        form_code='102101',
        form_number='第十号の二様式',
        form_name='訂正外国会社臨時報告書',
        doc_type_name='訂正臨時報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '103000'): FormCodeEntry(
        ordinance_code='010',
        form_code='103000',
        form_number='第十号の三様式',
        form_name='親会社等状況報告書（外国会社）',
        doc_type_name='親会社等状況報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '103001'): FormCodeEntry(
        ordinance_code='010',
        form_code='103001',
        form_number='第十号の三様式',
        form_name='訂正親会社等状況報告書（外国会社）',
        doc_type_name='訂正親会社等状況報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '104000'): FormCodeEntry(
        ordinance_code='010',
        form_code='104000',
        form_number='第十号の四様式',
        form_name='外国親会社等状況報告書',
        doc_type_name='親会社等状況報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '104001'): FormCodeEntry(
        ordinance_code='010',
        form_code='104001',
        form_number='第十号の四様式',
        form_name='訂正外国親会社等状況報告書',
        doc_type_name='訂正親会社等状況報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '110000'): FormCodeEntry(
        ordinance_code='010',
        form_code='110000',
        form_number='第十一号様式',
        form_name='発行登録書（株券､社債券等）',
        doc_type_name='発行登録書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '112000'): FormCodeEntry(
        ordinance_code='010',
        form_code='112000',
        form_number='第十一号の二様式',
        form_name='発行登録書（CP）',
        doc_type_name='発行登録書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '113001'): FormCodeEntry(
        ordinance_code='010',
        form_code='113001',
        form_number='第十一号の三様式',
        form_name='訂正発行登録書',
        doc_type_name='訂正発行登録書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '114004'): FormCodeEntry(
        ordinance_code='010',
        form_code='114004',
        form_number='第十一号の四様式',
        form_name='発行登録取下届出書',
        doc_type_name='発行登録取下届出書',
        disclosure_type='非開示',
        note=None,
    ),
    ('010', '11A000'): FormCodeEntry(
        ordinance_code='010',
        form_code='11A000',
        form_number='第十一号の二の二様式',
        form_name='発行登録書',
        doc_type_name='発行登録書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '120003'): FormCodeEntry(
        ordinance_code='010',
        form_code='120003',
        form_number='第十二号様式',
        form_name='発行登録追補書類（株券､社債券等）',
        doc_type_name='発行登録追補書類',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '122003'): FormCodeEntry(
        ordinance_code='010',
        form_code='122003',
        form_number='第十二号の二様式',
        form_name='発行登録追補書類（CP）',
        doc_type_name='発行登録追補書類',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '130001'): FormCodeEntry(
        ordinance_code='010',
        form_code='130001',
        form_number='第十三号様式',
        form_name='変更発行登録通知書',
        doc_type_name='変更通知書（発行登録通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('010', '130005'): FormCodeEntry(
        ordinance_code='010',
        form_code='130005',
        form_number='第十三号様式',
        form_name='発行登録通知書',
        doc_type_name='発行登録通知書',
        disclosure_type='非開示',
        note=None,
    ),
    ('010', '140000'): FormCodeEntry(
        ordinance_code='010',
        form_code='140000',
        form_number='第十四号様式',
        form_name='発行登録書',
        doc_type_name='発行登録書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '142001'): FormCodeEntry(
        ordinance_code='010',
        form_code='142001',
        form_number='第十四号の二様式',
        form_name='訂正発行登録書',
        doc_type_name='訂正発行登録書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '143004'): FormCodeEntry(
        ordinance_code='010',
        form_code='143004',
        form_number='第十四号の三様式',
        form_name='発行登録取下届出書',
        doc_type_name='発行登録取下届出書',
        disclosure_type='非開示',
        note=None,
    ),
    ('010', '144000'): FormCodeEntry(
        ordinance_code='010',
        form_code='144000',
        form_number='第十四号の四様式',
        form_name='発行登録書',
        doc_type_name='発行登録書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '150003'): FormCodeEntry(
        ordinance_code='010',
        form_code='150003',
        form_number='第十五号様式',
        form_name='発行登録追補書類',
        doc_type_name='発行登録追補書類',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '160001'): FormCodeEntry(
        ordinance_code='010',
        form_code='160001',
        form_number='第十六号様式',
        form_name='変更発行登録通知書',
        doc_type_name='変更通知書（発行登録通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('010', '160005'): FormCodeEntry(
        ordinance_code='010',
        form_code='160005',
        form_number='第十六号様式',
        form_name='発行登録通知書',
        doc_type_name='発行登録通知書',
        disclosure_type='非開示',
        note=None,
    ),
    ('010', '170000'): FormCodeEntry(
        ordinance_code='010',
        form_code='170000',
        form_number='第十七号様式',
        form_name='自己株券買付状況報告書（法２４条の６第１項に基づくもの）',
        doc_type_name='自己株券買付状況報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '170001'): FormCodeEntry(
        ordinance_code='010',
        form_code='170001',
        form_number='第十七号様式',
        form_name='訂正自己株券買付状況報告書（法２４条の６第１項に基づくもの）',
        doc_type_name='訂正自己株券買付状況報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '701001'): FormCodeEntry(
        ordinance_code='010',
        form_code='701001',
        form_number='XBRLの修正様式',
        form_name='XBRLの修正（内国会社－有価証券届出書）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '702001'): FormCodeEntry(
        ordinance_code='010',
        form_code='702001',
        form_number='XBRLの修正様式',
        form_name='XBRLの修正（内国会社－有価証券報告書）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '703001'): FormCodeEntry(
        ordinance_code='010',
        form_code='703001',
        form_number='XBRLの修正様式',
        form_name='XBRLの修正（内国会社－四半期報告書）',
        doc_type_name='訂正四半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '704001'): FormCodeEntry(
        ordinance_code='010',
        form_code='704001',
        form_number='XBRLの修正様式',
        form_name='XBRLの修正（内国会社－半期報告書）',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '711001'): FormCodeEntry(
        ordinance_code='010',
        form_code='711001',
        form_number='XBRLの修正様式',
        form_name='XBRLの修正（外国会社－有価証券届出書）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '712001'): FormCodeEntry(
        ordinance_code='010',
        form_code='712001',
        form_number='XBRLの修正様式',
        form_name='XBRLの修正（外国会社－有価証券報告書）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '713001'): FormCodeEntry(
        ordinance_code='010',
        form_code='713001',
        form_number='XBRLの修正様式',
        form_name='XBRLの修正（外国会社－四半期報告書）',
        doc_type_name='訂正四半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '714001'): FormCodeEntry(
        ordinance_code='010',
        form_code='714001',
        form_number='XBRLの修正様式',
        form_name='XBRLの修正（外国会社－半期報告書）',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '715001'): FormCodeEntry(
        ordinance_code='010',
        form_code='715001',
        form_number='XBRLの修正様式',
        form_name='XBRLの修正（外国会社－外国会社報告書）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '716001'): FormCodeEntry(
        ordinance_code='010',
        form_code='716001',
        form_number='XBRLの修正様式',
        form_name='XBRLの修正（外国会社－外国会社四半期報告書）',
        doc_type_name='訂正四半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '717001'): FormCodeEntry(
        ordinance_code='010',
        form_code='717001',
        form_number='XBRLの修正様式',
        form_name='XBRLの修正（外国会社－外国会社半期報告書）',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '718001'): FormCodeEntry(
        ordinance_code='010',
        form_code='718001',
        form_number='XBRLの修正様式',
        form_name='XBRLの修正（外国会社－外国会社届出書）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('010', '990004'): FormCodeEntry(
        ordinance_code='010',
        form_code='990004',
        form_number='様式なし',
        form_name='届出の取下げ願い（二号、二号の二、二号の三、二号の五、二号の六様式）',
        doc_type_name='届出の取下げ願い',
        disclosure_type='非開示',
        note=None,
    ),
    ('010', '991004'): FormCodeEntry(
        ordinance_code='010',
        form_code='991004',
        form_number='様式なし',
        form_name='届出の取下げ願い（二号の四、二号の七様式）',
        doc_type_name='届出の取下げ願い',
        disclosure_type='非開示',
        note=None,
    ),
    ('010', '992004'): FormCodeEntry(
        ordinance_code='010',
        form_code='992004',
        form_number='様式なし',
        form_name='届出の取下げ願い（七号～七号の五様式）',
        doc_type_name='届出の取下げ願い',
        disclosure_type='非開示',
        note=None,
    ),
    ('015', '010000'): FormCodeEntry(
        ordinance_code='015',
        form_code='010000',
        form_number='第一号様式',
        form_name='内部統制報告書',
        doc_type_name='内部統制報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('015', '010001'): FormCodeEntry(
        ordinance_code='015',
        form_code='010001',
        form_number='第一号様式',
        form_name='訂正内部統制報告書',
        doc_type_name='訂正内部統制報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('015', '020000'): FormCodeEntry(
        ordinance_code='015',
        form_code='020000',
        form_number='第二号様式',
        form_name='内部統制報告書',
        doc_type_name='内部統制報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('015', '020001'): FormCodeEntry(
        ordinance_code='015',
        form_code='020001',
        form_number='第二号様式',
        form_name='訂正内部統制報告書',
        doc_type_name='訂正内部統制報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('015', '030000'): FormCodeEntry(
        ordinance_code='015',
        form_code='030000',
        form_number='第三号様式',
        form_name='外国会社内部統制報告書',
        doc_type_name='内部統制報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('015', '030001'): FormCodeEntry(
        ordinance_code='015',
        form_code='030001',
        form_number='第三号様式',
        form_name='訂正外国会社内部統制報告書',
        doc_type_name='訂正内部統制報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('020', '010000'): FormCodeEntry(
        ordinance_code='020',
        form_code='010000',
        form_number='第一号様式',
        form_name='有価証券通知書',
        doc_type_name='有価証券通知書',
        disclosure_type='非開示',
        note=None,
    ),
    ('020', '010001'): FormCodeEntry(
        ordinance_code='020',
        form_code='010001',
        form_number='第一号様式',
        form_name='変更有価証券通知書',
        doc_type_name='変更通知書（有価証券通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('020', '020000'): FormCodeEntry(
        ordinance_code='020',
        form_code='020000',
        form_number='第二号様式',
        form_name='有価証券届出書（通常方式）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('020', '020001'): FormCodeEntry(
        ordinance_code='020',
        form_code='020001',
        form_number='第二号様式',
        form_name='訂正有価証券届出書（通常方式）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('020', '022000'): FormCodeEntry(
        ordinance_code='020',
        form_code='022000',
        form_number='第二号の二様式',
        form_name='有価証券届出書（組込方式）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('020', '022001'): FormCodeEntry(
        ordinance_code='020',
        form_code='022001',
        form_number='第二号の二様式',
        form_name='訂正有価証券届出書（組込方式）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('020', '023000'): FormCodeEntry(
        ordinance_code='020',
        form_code='023000',
        form_number='第二号の三様式',
        form_name='有価証券届出書（参照方式）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('020', '023001'): FormCodeEntry(
        ordinance_code='020',
        form_code='023001',
        form_number='第二号の三様式',
        form_name='訂正有価証券届出書（参照方式）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('020', '024000'): FormCodeEntry(
        ordinance_code='020',
        form_code='024000',
        form_number='第二号の四様式',
        form_name='外国者届出書',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('020', '024001'): FormCodeEntry(
        ordinance_code='020',
        form_code='024001',
        form_number='第二号の四様式',
        form_name='外国者訂正届出書',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('020', '030000'): FormCodeEntry(
        ordinance_code='020',
        form_code='030000',
        form_number='第三号様式',
        form_name='有価証券報告書',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('020', '030001'): FormCodeEntry(
        ordinance_code='020',
        form_code='030001',
        form_number='第三号様式',
        form_name='訂正有価証券報告書',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('020', '040000'): FormCodeEntry(
        ordinance_code='020',
        form_code='040000',
        form_number='第四号様式',
        form_name='有価証券報告書（法24条3項に基づくもの）',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('020', '040001'): FormCodeEntry(
        ordinance_code='020',
        form_code='040001',
        form_number='第四号様式',
        form_name='訂正有価証券報告書（法24条3項に基づくもの）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('020', '042000'): FormCodeEntry(
        ordinance_code='020',
        form_code='042000',
        form_number='第四号の二様式',
        form_name='外国者報告書',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('020', '042001'): FormCodeEntry(
        ordinance_code='020',
        form_code='042001',
        form_number='第四号の二様式',
        form_name='外国者訂正報告書',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('020', '042100'): FormCodeEntry(
        ordinance_code='020',
        form_code='042100',
        form_number='第四号の二様式',
        form_name='外国者半期報告書',
        doc_type_name='半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('020', '042101'): FormCodeEntry(
        ordinance_code='020',
        form_code='042101',
        form_number='第四号の二様式',
        form_name='外国者半期訂正報告書',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('020', '050000'): FormCodeEntry(
        ordinance_code='020',
        form_code='050000',
        form_number='第五号様式',
        form_name='半期報告書',
        doc_type_name='半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('020', '050001'): FormCodeEntry(
        ordinance_code='020',
        form_code='050001',
        form_number='第五号様式',
        form_name='訂正半期報告書',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('020', '060000'): FormCodeEntry(
        ordinance_code='020',
        form_code='060000',
        form_number='第六号様式',
        form_name='発行登録書',
        doc_type_name='発行登録書',
        disclosure_type='開示',
        note=None,
    ),
    ('020', '070001'): FormCodeEntry(
        ordinance_code='020',
        form_code='070001',
        form_number='第七号様式',
        form_name='訂正発行登録書',
        doc_type_name='訂正発行登録書',
        disclosure_type='開示',
        note=None,
    ),
    ('020', '080004'): FormCodeEntry(
        ordinance_code='020',
        form_code='080004',
        form_number='第八号様式',
        form_name='発行登録取下届出書',
        doc_type_name='発行登録取下届出書',
        disclosure_type='非開示',
        note=None,
    ),
    ('020', '090003'): FormCodeEntry(
        ordinance_code='020',
        form_code='090003',
        form_number='第九号様式',
        form_name='発行登録追補書類',
        doc_type_name='発行登録追補書類',
        disclosure_type='開示',
        note=None,
    ),
    ('020', '100001'): FormCodeEntry(
        ordinance_code='020',
        form_code='100001',
        form_number='第十号様式',
        form_name='変更発行登録通知書',
        doc_type_name='変更通知書（発行登録通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('020', '100005'): FormCodeEntry(
        ordinance_code='020',
        form_code='100005',
        form_number='第十号様式',
        form_name='発行登録通知書',
        doc_type_name='発行登録通知書',
        disclosure_type='非開示',
        note=None,
    ),
    ('020', '990004'): FormCodeEntry(
        ordinance_code='020',
        form_code='990004',
        form_number='様式なし',
        form_name='届出の取下げ願い',
        doc_type_name='届出の取下げ願い',
        disclosure_type='非開示',
        note=None,
    ),
    ('020', '999000'): FormCodeEntry(
        ordinance_code='020',
        form_code='999000',
        form_number='様式なし',
        form_name='臨時報告書',
        doc_type_name='臨時報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('020', '999001'): FormCodeEntry(
        ordinance_code='020',
        form_code='999001',
        form_number='様式なし',
        form_name='訂正臨時報告書',
        doc_type_name='訂正臨時報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('020', '999100'): FormCodeEntry(
        ordinance_code='020',
        form_code='999100',
        form_number='様式なし',
        form_name='外国者臨時報告書',
        doc_type_name='臨時報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('020', '999101'): FormCodeEntry(
        ordinance_code='020',
        form_code='999101',
        form_number='様式なし',
        form_name='訂正外国者臨時報告書',
        doc_type_name='訂正臨時報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '01A000'): FormCodeEntry(
        ordinance_code='030',
        form_code='01A000',
        form_number='第一号様式',
        form_name='有価証券通知書（内国投資信託受益証券）',
        doc_type_name='有価証券通知書',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '01A001'): FormCodeEntry(
        ordinance_code='030',
        form_code='01A001',
        form_number='第一号様式',
        form_name='変更有価証券通知書（内国投資信託受益証券）',
        doc_type_name='変更通知書（有価証券通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '01B000'): FormCodeEntry(
        ordinance_code='030',
        form_code='01B000',
        form_number='第一号の三様式',
        form_name='有価証券通知書（内国投資証券）',
        doc_type_name='有価証券通知書',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '01B001'): FormCodeEntry(
        ordinance_code='030',
        form_code='01B001',
        form_number='第一号の三様式',
        form_name='変更有価証券通知書（内国投資証券）',
        doc_type_name='変更通知書（有価証券通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '01C000'): FormCodeEntry(
        ordinance_code='030',
        form_code='01C000',
        form_number='第一号の二様式',
        form_name='有価証券通知書（外国投資信託受益証券）',
        doc_type_name='有価証券通知書',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '01C001'): FormCodeEntry(
        ordinance_code='030',
        form_code='01C001',
        form_number='第一号の二様式',
        form_name='変更有価証券通知書（外国投資信託受益証券）',
        doc_type_name='変更通知書（有価証券通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '01D000'): FormCodeEntry(
        ordinance_code='030',
        form_code='01D000',
        form_number='第二号様式',
        form_name='有価証券通知書（外国投資証券）',
        doc_type_name='有価証券通知書',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '01D001'): FormCodeEntry(
        ordinance_code='030',
        form_code='01D001',
        form_number='第二号様式',
        form_name='変更有価証券通知書（外国投資証券）',
        doc_type_name='変更通知書（有価証券通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '020001'): FormCodeEntry(
        ordinance_code='030',
        form_code='020001',
        form_number='第二号様式',
        form_name='変更有価証券通知書（外国貸付債権信託受益証券）',
        doc_type_name='変更通知書（有価証券通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '022000'): FormCodeEntry(
        ordinance_code='030',
        form_code='022000',
        form_number='第二号の二様式',
        form_name='有価証券通知書（内国資産流動化証券）',
        doc_type_name='有価証券通知書',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '022001'): FormCodeEntry(
        ordinance_code='030',
        form_code='022001',
        form_number='第二号の二様式',
        form_name='変更有価証券通知書（内国資産流動化証券）',
        doc_type_name='変更通知書（有価証券通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '023000'): FormCodeEntry(
        ordinance_code='030',
        form_code='023000',
        form_number='第二号の三様式',
        form_name='有価証券通知書（外国資産流動化証券）',
        doc_type_name='有価証券通知書',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '023001'): FormCodeEntry(
        ordinance_code='030',
        form_code='023001',
        form_number='第二号の三様式',
        form_name='変更有価証券通知書（外国資産流動化証券）',
        doc_type_name='変更通知書（有価証券通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '024000'): FormCodeEntry(
        ordinance_code='030',
        form_code='024000',
        form_number='第二号の四様式',
        form_name='有価証券通知書（内国資産信託流動化受益証券）',
        doc_type_name='有価証券通知書',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '024001'): FormCodeEntry(
        ordinance_code='030',
        form_code='024001',
        form_number='第二号の四様式',
        form_name='変更有価証券通知書（内国資産信託流動化受益証券）',
        doc_type_name='変更通知書（有価証券通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '025000'): FormCodeEntry(
        ordinance_code='030',
        form_code='025000',
        form_number='第二号の五様式',
        form_name='有価証券通知書（外国資産信託流動化受益証券）',
        doc_type_name='有価証券通知書',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '025001'): FormCodeEntry(
        ordinance_code='030',
        form_code='025001',
        form_number='第二号の五様式',
        form_name='変更有価証券通知書（外国資産信託流動化受益証券）',
        doc_type_name='変更通知書（有価証券通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '030001'): FormCodeEntry(
        ordinance_code='030',
        form_code='030001',
        form_number='第三号様式',
        form_name='変更有価証券通知書（貸付債権信託受益権）',
        doc_type_name='変更通知書（有価証券通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '032001'): FormCodeEntry(
        ordinance_code='030',
        form_code='032001',
        form_number='第三号の二様式',
        form_name='変更有価証券通知書（内国組合契約出資持分）',
        doc_type_name='変更通知書（有価証券通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '033001'): FormCodeEntry(
        ordinance_code='030',
        form_code='033001',
        form_number='第三号の三様式',
        form_name='変更有価証券通知書（外国組合契約出資持分）',
        doc_type_name='変更通知書（有価証券通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '03A000'): FormCodeEntry(
        ordinance_code='030',
        form_code='03A000',
        form_number='第三号様式',
        form_name='有価証券通知書（内国信託受益証券等）',
        doc_type_name='有価証券通知書',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '03A001'): FormCodeEntry(
        ordinance_code='030',
        form_code='03A001',
        form_number='第三号様式',
        form_name='変更有価証券通知書（内国信託受益証券等）',
        doc_type_name='変更通知書（有価証券通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '03B000'): FormCodeEntry(
        ordinance_code='030',
        form_code='03B000',
        form_number='第三号の二様式',
        form_name='有価証券通知書（外国信託受益証券等）',
        doc_type_name='有価証券通知書',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '03B001'): FormCodeEntry(
        ordinance_code='030',
        form_code='03B001',
        form_number='第三号の二様式',
        form_name='変更有価証券通知書（外国信託受益証券等）',
        doc_type_name='変更通知書（有価証券通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '03C000'): FormCodeEntry(
        ordinance_code='030',
        form_code='03C000',
        form_number='第三号の三様式',
        form_name='有価証券通知書（内国抵当証券）',
        doc_type_name='有価証券通知書',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '03C001'): FormCodeEntry(
        ordinance_code='030',
        form_code='03C001',
        form_number='第三号の三様式',
        form_name='変更有価証券通知書（内国抵当証券）',
        doc_type_name='変更通知書（有価証券通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '03D000'): FormCodeEntry(
        ordinance_code='030',
        form_code='03D000',
        form_number='第三号の四様式',
        form_name='有価証券通知書（外国抵当証券）',
        doc_type_name='有価証券通知書',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '03D001'): FormCodeEntry(
        ordinance_code='030',
        form_code='03D001',
        form_number='第三号の四様式',
        form_name='変更有価証券通知書（外国抵当証券）',
        doc_type_name='変更通知書（有価証券通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '03E000'): FormCodeEntry(
        ordinance_code='030',
        form_code='03E000',
        form_number='第三号の五様式',
        form_name='有価証券通知書（内国有価証券投資事業権利等）',
        doc_type_name='有価証券通知書',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '03E001'): FormCodeEntry(
        ordinance_code='030',
        form_code='03E001',
        form_number='第三号の五様式',
        form_name='変更有価証券通知書（内国有価証券投資事業権利等）',
        doc_type_name='変更通知書（有価証券通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '03F000'): FormCodeEntry(
        ordinance_code='030',
        form_code='03F000',
        form_number='第三号の六様式',
        form_name='有価証券通知書（外国有価証券投資事業権利等）',
        doc_type_name='有価証券通知書',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '03F001'): FormCodeEntry(
        ordinance_code='030',
        form_code='03F001',
        form_number='第三号の六様式',
        form_name='変更有価証券通知書（外国有価証券投資事業権利等）',
        doc_type_name='変更通知書（有価証券通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '04A000'): FormCodeEntry(
        ordinance_code='030',
        form_code='04A000',
        form_number='第四号様式',
        form_name='有価証券届出書（内国投資信託受益証券）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '04A001'): FormCodeEntry(
        ordinance_code='030',
        form_code='04A001',
        form_number='第四号様式',
        form_name='訂正有価証券届出書（内国投資信託受益証券）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '04B000'): FormCodeEntry(
        ordinance_code='030',
        form_code='04B000',
        form_number='第四号の三様式',
        form_name='有価証券届出書（内国投資証券）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '04B001'): FormCodeEntry(
        ordinance_code='030',
        form_code='04B001',
        form_number='第四号の三様式',
        form_name='訂正有価証券届出書（内国投資証券）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '04C000'): FormCodeEntry(
        ordinance_code='030',
        form_code='04C000',
        form_number='第四号の二様式',
        form_name='有価証券届出書（外国投資信託受益証券）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '04C001'): FormCodeEntry(
        ordinance_code='030',
        form_code='04C001',
        form_number='第四号の二様式',
        form_name='訂正有価証券届出書（外国投資信託受益証券）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '04C200'): FormCodeEntry(
        ordinance_code='030',
        form_code='04C200',
        form_number='第四号の二の二様式',
        form_name='外国会社届出書（外国投資信託受益証券）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '04C201'): FormCodeEntry(
        ordinance_code='030',
        form_code='04C201',
        form_number='第四号の二の二様式',
        form_name='外国会社訂正届出書（外国投資信託受益証券）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '04D000'): FormCodeEntry(
        ordinance_code='030',
        form_code='04D000',
        form_number='第四号の四様式',
        form_name='有価証券届出書（外国投資証券）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '04D001'): FormCodeEntry(
        ordinance_code='030',
        form_code='04D001',
        form_number='第四号の四様式',
        form_name='訂正有価証券届出書（外国投資証券）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '04E000'): FormCodeEntry(
        ordinance_code='030',
        form_code='04E000',
        form_number='第四号の三の二様式',
        form_name='有価証券届出書（組込方式・内国投資証券）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '04E001'): FormCodeEntry(
        ordinance_code='030',
        form_code='04E001',
        form_number='第四号の三の二様式',
        form_name='訂正有価証券届出書（組込方式・内国投資証券）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '04F000'): FormCodeEntry(
        ordinance_code='030',
        form_code='04F000',
        form_number='第四号の三の三様式',
        form_name='有価証券届出書（参照方式・内国投資証券）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '04F001'): FormCodeEntry(
        ordinance_code='030',
        form_code='04F001',
        form_number='第四号の三の三様式',
        form_name='訂正有価証券届出書（参照方式・内国投資証券）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '04G000'): FormCodeEntry(
        ordinance_code='030',
        form_code='04G000',
        form_number='第四号の四の二様式',
        form_name='有価証券届出書（組込方式・外国投資証券）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '04G001'): FormCodeEntry(
        ordinance_code='030',
        form_code='04G001',
        form_number='第四号の四の二様式',
        form_name='訂正有価証券届出書（組込方式・外国投資証券）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '04G300'): FormCodeEntry(
        ordinance_code='030',
        form_code='04G300',
        form_number='第四号の四の三様式',
        form_name='外国会社届出書（外国投資証券）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '04G301'): FormCodeEntry(
        ordinance_code='030',
        form_code='04G301',
        form_number='第四号の四の三様式',
        form_name='外国会社訂正届出書（外国投資証券）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '04H000'): FormCodeEntry(
        ordinance_code='030',
        form_code='04H000',
        form_number='第五号様式',
        form_name='有価証券届出書（参照方式・外国投資証券）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '04H001'): FormCodeEntry(
        ordinance_code='030',
        form_code='04H001',
        form_number='第五号様式',
        form_name='訂正有価証券届出書（参照方式・外国投資証券）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '050001'): FormCodeEntry(
        ordinance_code='030',
        form_code='050001',
        form_number='第五号様式',
        form_name='訂正有価証券届出書（外国貸付債権信託受益証券）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '052000'): FormCodeEntry(
        ordinance_code='030',
        form_code='052000',
        form_number='第五号の二様式',
        form_name='有価証券届出書（内国資産流動化証券）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '052001'): FormCodeEntry(
        ordinance_code='030',
        form_code='052001',
        form_number='第五号の二様式',
        form_name='訂正有価証券届出書（内国資産流動化証券）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '052200'): FormCodeEntry(
        ordinance_code='030',
        form_code='052200',
        form_number='第五号の二の二様式',
        form_name='有価証券届出書（組込方式・特定内国資産流動化証券）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '052201'): FormCodeEntry(
        ordinance_code='030',
        form_code='052201',
        form_number='第五号の二の二様式',
        form_name='訂正有価証券届出書（組込方式・特定内国資産流動化証券）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '052300'): FormCodeEntry(
        ordinance_code='030',
        form_code='052300',
        form_number='第五号の二の三様式',
        form_name='有価証券届出書（参照方式・特定内国資産流動化証券）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '052301'): FormCodeEntry(
        ordinance_code='030',
        form_code='052301',
        form_number='第五号の二の三様式',
        form_name='訂正有価証券届出書（参照方式・特定内国資産流動化証券）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '053000'): FormCodeEntry(
        ordinance_code='030',
        form_code='053000',
        form_number='第五号の三様式',
        form_name='有価証券届出書（外国資産流動化証券）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '053001'): FormCodeEntry(
        ordinance_code='030',
        form_code='053001',
        form_number='第五号の三様式',
        form_name='訂正有価証券届出書（外国資産流動化証券）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '053200'): FormCodeEntry(
        ordinance_code='030',
        form_code='053200',
        form_number='第五号の三の二様式',
        form_name='有価証券届出書（組込方式・特定外国資産流動化証券）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '053201'): FormCodeEntry(
        ordinance_code='030',
        form_code='053201',
        form_number='第五号の三の二様式',
        form_name='訂正有価証券届出書（組込方式・特定外国資産流動化証券）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '053300'): FormCodeEntry(
        ordinance_code='030',
        form_code='053300',
        form_number='第五号の三の三様式',
        form_name='有価証券届出書（参照方式・特定外国資産流動化証券）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '053301'): FormCodeEntry(
        ordinance_code='030',
        form_code='053301',
        form_number='第五号の三の三様式',
        form_name='訂正有価証券届出書（参照方式・特定外国資産流動化証券）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '053400'): FormCodeEntry(
        ordinance_code='030',
        form_code='053400',
        form_number='第五号の三の四様式',
        form_name='外国会社届出書（外国資産流動化証券）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '053401'): FormCodeEntry(
        ordinance_code='030',
        form_code='053401',
        form_number='第五号の三の四様式',
        form_name='外国会社訂正届出書（外国資産流動化証券）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '054000'): FormCodeEntry(
        ordinance_code='030',
        form_code='054000',
        form_number='第五号の四様式',
        form_name='有価証券届出書（内国資産信託流動化受益証券）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '054001'): FormCodeEntry(
        ordinance_code='030',
        form_code='054001',
        form_number='第五号の四様式',
        form_name='訂正有価証券届出書（内国資産信託流動化受益証券）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '055000'): FormCodeEntry(
        ordinance_code='030',
        form_code='055000',
        form_number='第五号の五様式',
        form_name='有価証券届出書（外国資産信託流動化受益証券）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '055001'): FormCodeEntry(
        ordinance_code='030',
        form_code='055001',
        form_number='第五号の五様式',
        form_name='訂正有価証券届出書（外国資産信託流動化受益証券）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '055200'): FormCodeEntry(
        ordinance_code='030',
        form_code='055200',
        form_number='第五号の五の二様式',
        form_name='外国会社届出書（外国資産信託流動化証券）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '055201'): FormCodeEntry(
        ordinance_code='030',
        form_code='055201',
        form_number='第五号の五の二様式',
        form_name='外国会社訂正届出書（外国資産信託流動化証券）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '060001'): FormCodeEntry(
        ordinance_code='030',
        form_code='060001',
        form_number='第六号様式',
        form_name='訂正有価証券届出書（貸付債権信託受益権）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '062001'): FormCodeEntry(
        ordinance_code='030',
        form_code='062001',
        form_number='第六号の二様式',
        form_name='訂正有価証券届出書（内国組合契約出資持分）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '063001'): FormCodeEntry(
        ordinance_code='030',
        form_code='063001',
        form_number='第六号の三様式',
        form_name='訂正有価証券届出書（外国組合契約出資持分）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '06A000'): FormCodeEntry(
        ordinance_code='030',
        form_code='06A000',
        form_number='第六号様式',
        form_name='有価証券届出書（内国信託受益証券等）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '06A001'): FormCodeEntry(
        ordinance_code='030',
        form_code='06A001',
        form_number='第六号様式',
        form_name='訂正有価証券届出書（内国信託受益証券等）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '06B000'): FormCodeEntry(
        ordinance_code='030',
        form_code='06B000',
        form_number='第六号の二様式',
        form_name='有価証券届出書（外国信託受益証券等）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '06B001'): FormCodeEntry(
        ordinance_code='030',
        form_code='06B001',
        form_number='第六号の二様式',
        form_name='訂正有価証券届出書（外国信託受益証券等）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '06B200'): FormCodeEntry(
        ordinance_code='030',
        form_code='06B200',
        form_number='第六号の二の二様式',
        form_name='外国会社届出書（外国信託受益証券）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '06B201'): FormCodeEntry(
        ordinance_code='030',
        form_code='06B201',
        form_number='第六号の二の二様式',
        form_name='外国会社訂正届出書（外国信託受益証券）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '06C000'): FormCodeEntry(
        ordinance_code='030',
        form_code='06C000',
        form_number='第六号の三様式',
        form_name='有価証券届出書（内国抵当証券）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '06C001'): FormCodeEntry(
        ordinance_code='030',
        form_code='06C001',
        form_number='第六号の三様式',
        form_name='訂正有価証券届出書（内国抵当証券）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '06D000'): FormCodeEntry(
        ordinance_code='030',
        form_code='06D000',
        form_number='第六号の四様式',
        form_name='有価証券届出書（外国抵当証券）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '06D001'): FormCodeEntry(
        ordinance_code='030',
        form_code='06D001',
        form_number='第六号の四様式',
        form_name='訂正有価証券届出書（外国抵当証券）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '06D200'): FormCodeEntry(
        ordinance_code='030',
        form_code='06D200',
        form_number='第六号の四の二様式',
        form_name='外国会社届出書（外国抵当証券）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '06D201'): FormCodeEntry(
        ordinance_code='030',
        form_code='06D201',
        form_number='第六号の四の二様式',
        form_name='外国会社訂正届出書（外国抵当証券）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '06E000'): FormCodeEntry(
        ordinance_code='030',
        form_code='06E000',
        form_number='第六号の五様式',
        form_name='有価証券届出書（内国有価証券投資事業権利等）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '06E001'): FormCodeEntry(
        ordinance_code='030',
        form_code='06E001',
        form_number='第六号の五様式',
        form_name='訂正有価証券届出書（内国有価証券投資事業権利等）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '06F000'): FormCodeEntry(
        ordinance_code='030',
        form_code='06F000',
        form_number='第六号の六様式',
        form_name='有価証券届出書（外国有価証券投資事業権利等）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '06F001'): FormCodeEntry(
        ordinance_code='030',
        form_code='06F001',
        form_number='第六号の六様式',
        form_name='訂正有価証券届出書（外国有価証券投資事業権利等）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '06F200'): FormCodeEntry(
        ordinance_code='030',
        form_code='06F200',
        form_number='第六号の六の二様式',
        form_name='外国会社届出書（外国有価証券投資事業権利等）',
        doc_type_name='有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '06F201'): FormCodeEntry(
        ordinance_code='030',
        form_code='06F201',
        form_number='第六号の六の二様式',
        form_name='外国会社訂正届出書（外国有価証券投資事業権利等）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '06G000'): FormCodeEntry(
        ordinance_code='030',
        form_code='06G000',
        form_number='第六号の七及び第七号様式',
        form_name='有価証券報告書（内国投資信託受益証券）',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note='みなし有価証券届出書',
    ),
    ('030', '06G001'): FormCodeEntry(
        ordinance_code='030',
        form_code='06G001',
        form_number='第六号の七及び第七号様式',
        form_name='訂正有価証券報告書（内国投資信託受益証券）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note='有価証券報告書及び有価証券届出書を同時に訂正する場合',
    ),
    ('030', '06G101'): FormCodeEntry(
        ordinance_code='030',
        form_code='06G101',
        form_number='第六号の七及び第七号様式',
        form_name='訂正有価証券届出書（内国投資信託受益証券）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note='有価証券報告書の訂正がない場合',
    ),
    ('030', '06G201'): FormCodeEntry(
        ordinance_code='030',
        form_code='06G201',
        form_number='第六号の七及び第七号様式',
        form_name='訂正有価証券報告書（内国投資信託受益証券）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note='有価証券届出書の訂正がない場合',
    ),
    ('030', '06H000'): FormCodeEntry(
        ordinance_code='030',
        form_code='06H000',
        form_number='第六号の八及び第七号の二様式',
        form_name='有価証券報告書（外国投資信託受益証券）',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note='みなし有価証券届出書',
    ),
    ('030', '06H001'): FormCodeEntry(
        ordinance_code='030',
        form_code='06H001',
        form_number='第六号の八及び第七号の二様式',
        form_name='訂正有価証券報告書（外国投資信託受益証券）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note='有価証券報告書及び有価証券届出書を同時に訂正する場合',
    ),
    ('030', '06H101'): FormCodeEntry(
        ordinance_code='030',
        form_code='06H101',
        form_number='第六号の八及び第七号の二様式',
        form_name='訂正有価証券届出書（外国投資信託受益証券）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note='有価証券報告書の訂正がない場合',
    ),
    ('030', '06H201'): FormCodeEntry(
        ordinance_code='030',
        form_code='06H201',
        form_number='第六号の八及び第七号の二様式',
        form_name='訂正有価証券報告書（外国投資信託受益証券）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note='有価証券届出書の訂正がない場合',
    ),
    ('030', '06I000'): FormCodeEntry(
        ordinance_code='030',
        form_code='06I000',
        form_number='第六号の九及び第九号様式',
        form_name='有価証券報告書（内国信託受益証券等）',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note='みなし有価証券届出書',
    ),
    ('030', '06I001'): FormCodeEntry(
        ordinance_code='030',
        form_code='06I001',
        form_number='第六号の九及び第九号様式',
        form_name='訂正有価証券報告書（内国信託受益証券等）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note='有価証券報告書及び有価証券届出書を同時に訂正する場合',
    ),
    ('030', '06I101'): FormCodeEntry(
        ordinance_code='030',
        form_code='06I101',
        form_number='第六号の九及び第九号様式',
        form_name='訂正有価証券届出書（内国信託受益証券等）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note='有価証券報告書の訂正がない場合',
    ),
    ('030', '06I201'): FormCodeEntry(
        ordinance_code='030',
        form_code='06I201',
        form_number='第六号の九及び第九号様式',
        form_name='訂正有価証券報告書（内国信託受益証券等）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note='有価証券届出書の訂正がない場合',
    ),
    ('030', '06J000'): FormCodeEntry(
        ordinance_code='030',
        form_code='06J000',
        form_number='第六号の十及び第九号の二様式',
        form_name='有価証券報告書（外国信託受益証券等）',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note='みなし有価証券届出書',
    ),
    ('030', '06J001'): FormCodeEntry(
        ordinance_code='030',
        form_code='06J001',
        form_number='第六号の十及び第九号の二様式',
        form_name='訂正有価証券報告書（外国信託受益証券等）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note='有価証券報告書及び有価証券届出書を同時に訂正する場合',
    ),
    ('030', '06J101'): FormCodeEntry(
        ordinance_code='030',
        form_code='06J101',
        form_number='第六号の十及び第九号の二様式',
        form_name='訂正有価証券届出書（外国信託受益証券等）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note='有価証券報告書の訂正がない場合',
    ),
    ('030', '06J201'): FormCodeEntry(
        ordinance_code='030',
        form_code='06J201',
        form_number='第六号の十及び第九号の二様式',
        form_name='訂正有価証券報告書（外国信託受益証券等）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note='有価証券届出書の訂正がない場合',
    ),
    ('030', '07A000'): FormCodeEntry(
        ordinance_code='030',
        form_code='07A000',
        form_number='第七号様式',
        form_name='有価証券報告書（内国投資信託受益証券）',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '07A001'): FormCodeEntry(
        ordinance_code='030',
        form_code='07A001',
        form_number='第七号様式',
        form_name='訂正有価証券報告書（内国投資信託受益証券）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '07B000'): FormCodeEntry(
        ordinance_code='030',
        form_code='07B000',
        form_number='第七号の三様式',
        form_name='有価証券報告書（内国投資証券）',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '07B001'): FormCodeEntry(
        ordinance_code='030',
        form_code='07B001',
        form_number='第七号の三様式',
        form_name='訂正有価証券報告書（内国投資証券）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '07C000'): FormCodeEntry(
        ordinance_code='030',
        form_code='07C000',
        form_number='第七号の二様式',
        form_name='有価証券報告書（外国投資信託受益証券）',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '07C001'): FormCodeEntry(
        ordinance_code='030',
        form_code='07C001',
        form_number='第七号の二様式',
        form_name='訂正有価証券報告書（外国投資信託受益証券）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '07D000'): FormCodeEntry(
        ordinance_code='030',
        form_code='07D000',
        form_number='第八号様式',
        form_name='有価証券報告書（外国投資証券）',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '07D001'): FormCodeEntry(
        ordinance_code='030',
        form_code='07D001',
        form_number='第八号様式',
        form_name='訂正有価証券報告書（外国投資証券）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '07I000'): FormCodeEntry(
        ordinance_code='030',
        form_code='07I000',
        form_number='第七号の二の二様式',
        form_name='外国会社報告書',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '07I001'): FormCodeEntry(
        ordinance_code='030',
        form_code='07I001',
        form_number='第七号の二の二様式',
        form_name='外国会社訂正報告書',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '080000'): FormCodeEntry(
        ordinance_code='030',
        form_code='080000',
        form_number='第八号様式',
        form_name='有価証券報告書（外国貸付債権信託受益証券）',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '080001'): FormCodeEntry(
        ordinance_code='030',
        form_code='080001',
        form_number='第八号様式',
        form_name='訂正有価証券報告書（外国貸付債権信託受益証券）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '082000'): FormCodeEntry(
        ordinance_code='030',
        form_code='082000',
        form_number='第八号の二様式',
        form_name='有価証券報告書（内国資産流動化証券）',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '082001'): FormCodeEntry(
        ordinance_code='030',
        form_code='082001',
        form_number='第八号の二様式',
        form_name='訂正有価証券報告書（内国資産流動化証券）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '083000'): FormCodeEntry(
        ordinance_code='030',
        form_code='083000',
        form_number='第八号の三様式',
        form_name='有価証券報告書（外国資産流動化証券）',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '083001'): FormCodeEntry(
        ordinance_code='030',
        form_code='083001',
        form_number='第八号の三様式',
        form_name='訂正有価証券報告書（外国資産流動化証券）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '084000'): FormCodeEntry(
        ordinance_code='030',
        form_code='084000',
        form_number='第八号の四様式',
        form_name='有価証券報告書（内国資産信託流動化受益証券）',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '084001'): FormCodeEntry(
        ordinance_code='030',
        form_code='084001',
        form_number='第八号の四様式',
        form_name='訂正有価証券報告書（内国資産信託流動化受益証券）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '085000'): FormCodeEntry(
        ordinance_code='030',
        form_code='085000',
        form_number='第八号の五様式',
        form_name='有価証券報告書（外国資産信託流動化受益証券）',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '085001'): FormCodeEntry(
        ordinance_code='030',
        form_code='085001',
        form_number='第八号の五様式',
        form_name='訂正有価証券報告書（外国資産信託流動化受益証券）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '090000'): FormCodeEntry(
        ordinance_code='030',
        form_code='090000',
        form_number='第九号様式',
        form_name='有価証券報告書（貸付債権信託受益権）',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '090001'): FormCodeEntry(
        ordinance_code='030',
        form_code='090001',
        form_number='第九号様式',
        form_name='訂正有価証券報告書（貸付債権信託受益権）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '092000'): FormCodeEntry(
        ordinance_code='030',
        form_code='092000',
        form_number='第九号の二様式',
        form_name='有価証券報告書（内国組合契約出資持分）',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '092001'): FormCodeEntry(
        ordinance_code='030',
        form_code='092001',
        form_number='第九号の二様式',
        form_name='訂正有価証券報告書（内国組合契約出資持分）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '093000'): FormCodeEntry(
        ordinance_code='030',
        form_code='093000',
        form_number='第九号の三様式',
        form_name='有価証券報告書（外国組合契約出資持分）',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '093001'): FormCodeEntry(
        ordinance_code='030',
        form_code='093001',
        form_number='第九号の三様式',
        form_name='訂正有価証券報告書（外国組合契約出資持分）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '09A000'): FormCodeEntry(
        ordinance_code='030',
        form_code='09A000',
        form_number='第九号様式',
        form_name='有価証券報告書（内国信託受益証券等）',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '09A001'): FormCodeEntry(
        ordinance_code='030',
        form_code='09A001',
        form_number='第九号様式',
        form_name='訂正有価証券報告書（内国信託受益証券等）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '09B000'): FormCodeEntry(
        ordinance_code='030',
        form_code='09B000',
        form_number='第九号の二様式',
        form_name='有価証券報告書（外国信託受益証券等）',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '09B001'): FormCodeEntry(
        ordinance_code='030',
        form_code='09B001',
        form_number='第九号の二様式',
        form_name='訂正有価証券報告書（外国信託受益証券等）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '09C000'): FormCodeEntry(
        ordinance_code='030',
        form_code='09C000',
        form_number='第九号の三様式',
        form_name='有価証券報告書（内国抵当証券）',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '09C001'): FormCodeEntry(
        ordinance_code='030',
        form_code='09C001',
        form_number='第九号の三様式',
        form_name='訂正有価証券報告書（内国抵当証券）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '09D000'): FormCodeEntry(
        ordinance_code='030',
        form_code='09D000',
        form_number='第九号の四様式',
        form_name='有価証券報告書（外国抵当証券）',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '09D001'): FormCodeEntry(
        ordinance_code='030',
        form_code='09D001',
        form_number='第九号の四様式',
        form_name='訂正有価証券報告書（外国抵当証券）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '09E000'): FormCodeEntry(
        ordinance_code='030',
        form_code='09E000',
        form_number='第九号の五様式',
        form_name='有価証券報告書（内国有価証券投資事業権利等）',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '09E001'): FormCodeEntry(
        ordinance_code='030',
        form_code='09E001',
        form_number='第九号の五様式',
        form_name='訂正有価証券報告書（内国有価証券投資事業権利等）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '09F000'): FormCodeEntry(
        ordinance_code='030',
        form_code='09F000',
        form_number='第九号の六様式',
        form_name='有価証券報告書（外国有価証券投資事業権利等）',
        doc_type_name='有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '09F001'): FormCodeEntry(
        ordinance_code='030',
        form_code='09F001',
        form_number='第九号の六様式',
        form_name='訂正有価証券報告書（外国有価証券投資事業権利等）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '10A000'): FormCodeEntry(
        ordinance_code='030',
        form_code='10A000',
        form_number='第十号様式',
        form_name='半期報告書（内国投資信託受益証券）',
        doc_type_name='半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '10A001'): FormCodeEntry(
        ordinance_code='030',
        form_code='10A001',
        form_number='第十号様式',
        form_name='訂正半期報告書（内国投資信託受益証券）',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '10B000'): FormCodeEntry(
        ordinance_code='030',
        form_code='10B000',
        form_number='第十号の三様式',
        form_name='半期報告書（内国投資証券）',
        doc_type_name='半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '10B001'): FormCodeEntry(
        ordinance_code='030',
        form_code='10B001',
        form_number='第十号の三様式',
        form_name='訂正半期報告書（内国投資証券）',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '10C000'): FormCodeEntry(
        ordinance_code='030',
        form_code='10C000',
        form_number='第十号の二様式',
        form_name='半期報告書（外国投資信託受益証券）',
        doc_type_name='半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '10C001'): FormCodeEntry(
        ordinance_code='030',
        form_code='10C001',
        form_number='第十号の二様式',
        form_name='訂正半期報告書（外国投資信託受益証券）',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '10D000'): FormCodeEntry(
        ordinance_code='030',
        form_code='10D000',
        form_number='第十一号様式',
        form_name='半期報告書（外国投資証券）',
        doc_type_name='半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '10D001'): FormCodeEntry(
        ordinance_code='030',
        form_code='10D001',
        form_number='第十一号様式',
        form_name='訂正半期報告書（外国投資証券）',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '10I000'): FormCodeEntry(
        ordinance_code='030',
        form_code='10I000',
        form_number='第十号の二の二様式',
        form_name='外国会社半期報告書',
        doc_type_name='半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '10I001'): FormCodeEntry(
        ordinance_code='030',
        form_code='10I001',
        form_number='第十号の二の二様式',
        form_name='外国会社半期訂正報告書（上場外国投資信託受益証券）',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '110000'): FormCodeEntry(
        ordinance_code='030',
        form_code='110000',
        form_number='第十一号様式',
        form_name='半期報告書（外国貸付債権信託受益証券）',
        doc_type_name='半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '110001'): FormCodeEntry(
        ordinance_code='030',
        form_code='110001',
        form_number='第十一号様式',
        form_name='訂正半期報告書（外国貸付債権信託受益証券）',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '112000'): FormCodeEntry(
        ordinance_code='030',
        form_code='112000',
        form_number='第十一号の二様式',
        form_name='半期報告書（内国資産流動化証券）',
        doc_type_name='半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '112001'): FormCodeEntry(
        ordinance_code='030',
        form_code='112001',
        form_number='第十一号の二様式',
        form_name='訂正半期報告書（内国資産流動化証券）',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '113000'): FormCodeEntry(
        ordinance_code='030',
        form_code='113000',
        form_number='第十一号の三様式',
        form_name='半期報告書（外国資産流動化証券）',
        doc_type_name='半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '113001'): FormCodeEntry(
        ordinance_code='030',
        form_code='113001',
        form_number='第十一号の三様式',
        form_name='訂正半期報告書（外国資産流動化証券）',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '114000'): FormCodeEntry(
        ordinance_code='030',
        form_code='114000',
        form_number='第十一号の四様式',
        form_name='半期報告書（内国資産信託流動化受益証券）',
        doc_type_name='半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '114001'): FormCodeEntry(
        ordinance_code='030',
        form_code='114001',
        form_number='第十一号の四様式',
        form_name='訂正半期報告書（内国資産信託流動化受益証券）',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '115000'): FormCodeEntry(
        ordinance_code='030',
        form_code='115000',
        form_number='第十一号の五様式',
        form_name='半期報告書（外国資産信託流動化受益証券）',
        doc_type_name='半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '115001'): FormCodeEntry(
        ordinance_code='030',
        form_code='115001',
        form_number='第十一号の五様式',
        form_name='訂正半期報告書（外国資産信託流動化受益証券）',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '120000'): FormCodeEntry(
        ordinance_code='030',
        form_code='120000',
        form_number='第十二号様式',
        form_name='半期報告書（貸付債権信託受益権）',
        doc_type_name='半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '120001'): FormCodeEntry(
        ordinance_code='030',
        form_code='120001',
        form_number='第十二号様式',
        form_name='訂正半期報告書（貸付債権信託受益権）',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '122000'): FormCodeEntry(
        ordinance_code='030',
        form_code='122000',
        form_number='第十二号の二様式',
        form_name='半期報告書（内国組合契約出資持分）',
        doc_type_name='半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '122001'): FormCodeEntry(
        ordinance_code='030',
        form_code='122001',
        form_number='第十二号の二様式',
        form_name='訂正半期報告書（内国組合契約出資持分）',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '123000'): FormCodeEntry(
        ordinance_code='030',
        form_code='123000',
        form_number='第十二号の三様式',
        form_name='半期報告書（外国組合契約出資持分）',
        doc_type_name='半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '123001'): FormCodeEntry(
        ordinance_code='030',
        form_code='123001',
        form_number='第十二号の三様式',
        form_name='訂正半期報告書（外国組合契約出資持分）',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '12A000'): FormCodeEntry(
        ordinance_code='030',
        form_code='12A000',
        form_number='第十二号様式',
        form_name='半期報告書（内国信託受益証券等）',
        doc_type_name='半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '12A001'): FormCodeEntry(
        ordinance_code='030',
        form_code='12A001',
        form_number='第十二号様式',
        form_name='訂正半期報告書（内国信託受益証券等）',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '12B000'): FormCodeEntry(
        ordinance_code='030',
        form_code='12B000',
        form_number='第十二号の二様式',
        form_name='半期報告書（外国信託受益証券等）',
        doc_type_name='半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '12B001'): FormCodeEntry(
        ordinance_code='030',
        form_code='12B001',
        form_number='第十二号の二様式',
        form_name='訂正半期報告書（外国信託受益証券等）',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '12C000'): FormCodeEntry(
        ordinance_code='030',
        form_code='12C000',
        form_number='第十二号の三様式',
        form_name='半期報告書（内国抵当証券）',
        doc_type_name='半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '12C001'): FormCodeEntry(
        ordinance_code='030',
        form_code='12C001',
        form_number='第十二号の三様式',
        form_name='訂正半期報告書（内国抵当証券）',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '12D000'): FormCodeEntry(
        ordinance_code='030',
        form_code='12D000',
        form_number='第十二号の四様式',
        form_name='半期報告書（外国抵当証券）',
        doc_type_name='半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '12D001'): FormCodeEntry(
        ordinance_code='030',
        form_code='12D001',
        form_number='第十二号の四様式',
        form_name='訂正半期報告書（外国抵当証券）',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '12E000'): FormCodeEntry(
        ordinance_code='030',
        form_code='12E000',
        form_number='第十二号の五様式',
        form_name='半期報告書（内国有価証券投資事業権利等）',
        doc_type_name='半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '12E001'): FormCodeEntry(
        ordinance_code='030',
        form_code='12E001',
        form_number='第十二号の五様式',
        form_name='訂正半期報告書（内国有価証券投資事業権利等）',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '12F000'): FormCodeEntry(
        ordinance_code='030',
        form_code='12F000',
        form_number='第十二号の六様式',
        form_name='半期報告書（外国有価証券投資事業権利等）',
        doc_type_name='半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '12F001'): FormCodeEntry(
        ordinance_code='030',
        form_code='12F001',
        form_number='第十二号の六様式',
        form_name='訂正半期報告書（外国有価証券投資事業権利等）',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '150000'): FormCodeEntry(
        ordinance_code='030',
        form_code='150000',
        form_number='第十五号様式',
        form_name='発行登録書（内国投資証券）',
        doc_type_name='発行登録書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '152000'): FormCodeEntry(
        ordinance_code='030',
        form_code='152000',
        form_number='第十五号の三様式',
        form_name='発行登録書（短期投資法人債）',
        doc_type_name='発行登録書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '15A000'): FormCodeEntry(
        ordinance_code='030',
        form_code='15A000',
        form_number='第十五号の二様式',
        form_name='発行登録書（特定内国資産流動化証券）',
        doc_type_name='発行登録書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '160000'): FormCodeEntry(
        ordinance_code='030',
        form_code='160000',
        form_number='第十六号様式',
        form_name='発行登録書（外国投資証券）',
        doc_type_name='発行登録書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '162000'): FormCodeEntry(
        ordinance_code='030',
        form_code='162000',
        form_number='第十六号の三様式（旧第十六号の二様式）',
        form_name='発行登録書（短期外債）',
        doc_type_name='発行登録書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '16A000'): FormCodeEntry(
        ordinance_code='030',
        form_code='16A000',
        form_number='第十六号の二様式',
        form_name='発行登録書（特定外国資産流動化証券）',
        doc_type_name='発行登録書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '170001'): FormCodeEntry(
        ordinance_code='030',
        form_code='170001',
        form_number='第十七号様式',
        form_name='訂正発行登録書（内国投資証券）',
        doc_type_name='訂正発行登録書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '172001'): FormCodeEntry(
        ordinance_code='030',
        form_code='172001',
        form_number='第十七号の二様式',
        form_name='訂正発行登録書（特定内国資産流動化証券）',
        doc_type_name='訂正発行登録書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '180001'): FormCodeEntry(
        ordinance_code='030',
        form_code='180001',
        form_number='第十八号様式',
        form_name='訂正発行登録書（外国投資証券）',
        doc_type_name='訂正発行登録書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '182001'): FormCodeEntry(
        ordinance_code='030',
        form_code='182001',
        form_number='第十八号の二様式',
        form_name='訂正発行登録書（特定外国資産流動化証券）',
        doc_type_name='訂正発行登録書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '190004'): FormCodeEntry(
        ordinance_code='030',
        form_code='190004',
        form_number='第十九号様式',
        form_name='発行登録取下届出書（内国投資証券）',
        doc_type_name='発行登録取下届出書',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '192004'): FormCodeEntry(
        ordinance_code='030',
        form_code='192004',
        form_number='第十九号の二様式',
        form_name='発行登録取下届出書（特定内国資産流動化証券）',
        doc_type_name='発行登録取下届出書',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '200004'): FormCodeEntry(
        ordinance_code='030',
        form_code='200004',
        form_number='第二十号様式',
        form_name='発行登録取下届出書（外国投資証券）',
        doc_type_name='発行登録取下届出書',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '202004'): FormCodeEntry(
        ordinance_code='030',
        form_code='202004',
        form_number='第二十号の二様式',
        form_name='発行登録取下届出書（特定外国資産流動化証券）',
        doc_type_name='発行登録取下届出書',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '210003'): FormCodeEntry(
        ordinance_code='030',
        form_code='210003',
        form_number='第二十一号様式',
        form_name='発行登録追補書類（内国投資証券）',
        doc_type_name='発行登録追補書類',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '212003'): FormCodeEntry(
        ordinance_code='030',
        form_code='212003',
        form_number='第二十一号の二様式',
        form_name='発行登録追補書類（特定内国資産流動化証券）',
        doc_type_name='発行登録追補書類',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '220003'): FormCodeEntry(
        ordinance_code='030',
        form_code='220003',
        form_number='第二十二号様式',
        form_name='発行登録追補書類（外国投資証券）',
        doc_type_name='発行登録追補書類',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '222003'): FormCodeEntry(
        ordinance_code='030',
        form_code='222003',
        form_number='第二十二号の二様式',
        form_name='発行登録追補書類（特定外国資産流動化証券）',
        doc_type_name='発行登録追補書類',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '230001'): FormCodeEntry(
        ordinance_code='030',
        form_code='230001',
        form_number='第二十三号様式',
        form_name='変更発行登録通知書（内国投資証券）',
        doc_type_name='変更通知書（発行登録通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '230005'): FormCodeEntry(
        ordinance_code='030',
        form_code='230005',
        form_number='第二十三号様式',
        form_name='発行登録通知書（内国投資証券）',
        doc_type_name='発行登録通知書',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '232001'): FormCodeEntry(
        ordinance_code='030',
        form_code='232001',
        form_number='第二十三号の二様式',
        form_name='変更発行登録通知書（特定内国資産流動化証券）',
        doc_type_name='変更通知書（発行登録通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '232005'): FormCodeEntry(
        ordinance_code='030',
        form_code='232005',
        form_number='第二十三号の二様式',
        form_name='発行登録通知書（特定内国資産流動化証券）',
        doc_type_name='発行登録通知書',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '240001'): FormCodeEntry(
        ordinance_code='030',
        form_code='240001',
        form_number='第二十四号様式',
        form_name='変更発行登録通知書（外国投資証券）',
        doc_type_name='変更通知書（発行登録通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '240005'): FormCodeEntry(
        ordinance_code='030',
        form_code='240005',
        form_number='第二十四号様式',
        form_name='発行登録通知書（外国投資証券）',
        doc_type_name='発行登録通知書',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '242001'): FormCodeEntry(
        ordinance_code='030',
        form_code='242001',
        form_number='第二十四号の二様式',
        form_name='変更発行登録通知書（特定外国資産流動化証券）',
        doc_type_name='変更通知書（発行登録通知書）',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '242005'): FormCodeEntry(
        ordinance_code='030',
        form_code='242005',
        form_number='第二十四号の二様式',
        form_name='発行登録通知書（特定外国資産流動化証券）',
        doc_type_name='発行登録通知書',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '253000'): FormCodeEntry(
        ordinance_code='030',
        form_code='253000',
        form_number='第二十五号の三様式',
        form_name='自己株券買付状況報告書（法２４条の６第１項に基づくもの）',
        doc_type_name='自己株券買付状況報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '253001'): FormCodeEntry(
        ordinance_code='030',
        form_code='253001',
        form_number='第二十五号の三様式',
        form_name='訂正自己株券買付状況報告書（法２４条の６第１項に基づくもの）',
        doc_type_name='訂正自己株券買付状況報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '701001'): FormCodeEntry(
        ordinance_code='030',
        form_code='701001',
        form_number='XBRLの修正様式',
        form_name='XBRLの修正（特定有価証券－有価証券届出書）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '702001'): FormCodeEntry(
        ordinance_code='030',
        form_code='702001',
        form_number='XBRLの修正様式',
        form_name='XBRLの修正（特定有価証券－有価証券報告書）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '706001'): FormCodeEntry(
        ordinance_code='030',
        form_code='706001',
        form_number='XBRLの修正様式',
        form_name='XBRLの修正（特定有価証券－半期報告書）',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '707001'): FormCodeEntry(
        ordinance_code='030',
        form_code='707001',
        form_number='XBRLの修正様式',
        form_name='XBRLの修正（特定有価証券－外国会社報告書）',
        doc_type_name='訂正有価証券報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '708001'): FormCodeEntry(
        ordinance_code='030',
        form_code='708001',
        form_number='XBRLの修正様式',
        form_name='XBRLの修正（特定有価証券－外国会社半期報告書）',
        doc_type_name='訂正半期報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '709001'): FormCodeEntry(
        ordinance_code='030',
        form_code='709001',
        form_number='XBRLの修正様式',
        form_name='XBRLの修正（特定有価証券－外国会社届出書）',
        doc_type_name='訂正有価証券届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '990004'): FormCodeEntry(
        ordinance_code='030',
        form_code='990004',
        form_number='様式なし',
        form_name='届出の取下げ願い（四号、四号の三、四号の三の二、四号の三の三、五号の二、六号の五様式）',
        doc_type_name='届出の取下げ願い',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '991004'): FormCodeEntry(
        ordinance_code='030',
        form_code='991004',
        form_number='様式なし',
        form_name='届出の取下げ願い（六号の三、六号の四、六号の四の二様式）',
        doc_type_name='届出の取下げ願い',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '992004'): FormCodeEntry(
        ordinance_code='030',
        form_code='992004',
        form_number='様式なし',
        form_name='届出の取下げ願い（四号の二、四号の二の二、四号の四、四号の四の二、四号の四の三、五号様式）',
        doc_type_name='届出の取下げ願い',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '993004'): FormCodeEntry(
        ordinance_code='030',
        form_code='993004',
        form_number='様式なし',
        form_name='届出の取下げ願い（五号の三、五号の三の四、六号の六、六号の六の二様式）',
        doc_type_name='届出の取下げ願い',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '994004'): FormCodeEntry(
        ordinance_code='030',
        form_code='994004',
        form_number='様式なし',
        form_name='届出の取下げ願い（五号の四、六号様式）',
        doc_type_name='届出の取下げ願い',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '995000'): FormCodeEntry(
        ordinance_code='030',
        form_code='995000',
        form_number='様式なし',
        form_name='臨時報告書（内国特定有価証券）',
        doc_type_name='臨時報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '995001'): FormCodeEntry(
        ordinance_code='030',
        form_code='995001',
        form_number='様式なし',
        form_name='訂正臨時報告書（内国特定有価証券）',
        doc_type_name='訂正臨時報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '995004'): FormCodeEntry(
        ordinance_code='030',
        form_code='995004',
        form_number='様式なし',
        form_name='届出の取下げ願い（五号の五、五号の五の二、六号の二、六号の二の二様式）',
        doc_type_name='届出の取下げ願い',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '996004'): FormCodeEntry(
        ordinance_code='030',
        form_code='996004',
        form_number='様式なし',
        form_name='届出の取下げ願い（第五号の二のニ様式、第五号のニの三様式）',
        doc_type_name='届出の取下げ願い',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '997004'): FormCodeEntry(
        ordinance_code='030',
        form_code='997004',
        form_number='様式なし',
        form_name='届出の取下げ願い（第五号の三のニ様式、第五号の三の三様式）',
        doc_type_name='届出の取下げ願い',
        disclosure_type='非開示',
        note=None,
    ),
    ('030', '999000'): FormCodeEntry(
        ordinance_code='030',
        form_code='999000',
        form_number='様式なし',
        form_name='臨時報告書（外国特定有価証券）',
        doc_type_name='臨時報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '999001'): FormCodeEntry(
        ordinance_code='030',
        form_code='999001',
        form_number='様式なし',
        form_name='訂正臨時報告書（外国特定有価証券）',
        doc_type_name='訂正臨時報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '999100'): FormCodeEntry(
        ordinance_code='030',
        form_code='999100',
        form_number='様式なし',
        form_name='外国会社臨時報告書（外国特定有価証券）',
        doc_type_name='臨時報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('030', '999101'): FormCodeEntry(
        ordinance_code='030',
        form_code='999101',
        form_number='様式なし',
        form_name='訂正外国会社臨時報告書（外国特定有価証券）',
        doc_type_name='訂正臨時報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('040', '020000'): FormCodeEntry(
        ordinance_code='040',
        form_code='020000',
        form_number='第二号様式',
        form_name='公開買付届出書',
        doc_type_name='公開買付届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('040', '020001'): FormCodeEntry(
        ordinance_code='040',
        form_code='020001',
        form_number='第二号様式',
        form_name='訂正公開買付届出書',
        doc_type_name='訂正公開買付届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('040', '030000'): FormCodeEntry(
        ordinance_code='040',
        form_code='030000',
        form_number='第三号様式',
        form_name='別途買付け禁止の特例を受けるための申出書',
        doc_type_name='別途買付け禁止の特例を受けるための申出書',
        disclosure_type='非開示',
        note=None,
    ),
    ('040', '030001'): FormCodeEntry(
        ordinance_code='040',
        form_code='030001',
        form_number='第三号様式',
        form_name='訂正別途買付け禁止の特例を受けるための申出書',
        doc_type_name='訂正別途買付け禁止の特例を受けるための申出書',
        disclosure_type='非開示',
        note=None,
    ),
    ('040', '040000'): FormCodeEntry(
        ordinance_code='040',
        form_code='040000',
        form_number='第四号様式',
        form_name='意見表明報告書',
        doc_type_name='意見表明報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('040', '040001'): FormCodeEntry(
        ordinance_code='040',
        form_code='040001',
        form_number='第四号様式',
        form_name='訂正意見表明報告書',
        doc_type_name='訂正意見表明報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('040', '050006'): FormCodeEntry(
        ordinance_code='040',
        form_code='050006',
        form_number='第五号様式',
        form_name='公開買付撤回届出書',
        doc_type_name='公開買付撤回届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('040', '060001'): FormCodeEntry(
        ordinance_code='040',
        form_code='060001',
        form_number='第六号様式',
        form_name='訂正公開買付報告書',
        doc_type_name='訂正公開買付報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('040', '060007'): FormCodeEntry(
        ordinance_code='040',
        form_code='060007',
        form_number='第六号様式',
        form_name='公開買付報告書',
        doc_type_name='公開買付報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('040', '080001'): FormCodeEntry(
        ordinance_code='040',
        form_code='080001',
        form_number='第八号様式',
        form_name='訂正対質問回答報告書',
        doc_type_name='訂正対質問回答報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('040', '080008'): FormCodeEntry(
        ordinance_code='040',
        form_code='080008',
        form_number='第八号様式',
        form_name='対質問回答報告書',
        doc_type_name='対質問回答報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('050', '020000'): FormCodeEntry(
        ordinance_code='050',
        form_code='020000',
        form_number='第二号様式',
        form_name='公開買付届出書',
        doc_type_name='公開買付届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('050', '020001'): FormCodeEntry(
        ordinance_code='050',
        form_code='020001',
        form_number='第二号様式',
        form_name='訂正公開買付届出書',
        doc_type_name='訂正公開買付届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('050', '030006'): FormCodeEntry(
        ordinance_code='050',
        form_code='030006',
        form_number='第三号様式',
        form_name='公開買付撤回届出書',
        doc_type_name='公開買付撤回届出書',
        disclosure_type='開示',
        note=None,
    ),
    ('050', '040001'): FormCodeEntry(
        ordinance_code='050',
        form_code='040001',
        form_number='第四号様式',
        form_name='訂正公開買付報告書',
        doc_type_name='訂正公開買付報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('050', '040007'): FormCodeEntry(
        ordinance_code='050',
        form_code='040007',
        form_number='第四号様式',
        form_name='公開買付報告書',
        doc_type_name='公開買付報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('060', '010000'): FormCodeEntry(
        ordinance_code='060',
        form_code='010000',
        form_number='第一号様式',
        form_name='大量保有報告書',
        doc_type_name='大量保有報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('060', '010002'): FormCodeEntry(
        ordinance_code='060',
        form_code='010002',
        form_number='第一号様式',
        form_name='変更報告書',
        doc_type_name='大量保有報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('060', '020002'): FormCodeEntry(
        ordinance_code='060',
        form_code='020002',
        form_number='第一号及び第二号様式',
        form_name='変更報告書（短期大量譲渡）',
        doc_type_name='大量保有報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('060', '030000'): FormCodeEntry(
        ordinance_code='060',
        form_code='030000',
        form_number='第三号様式',
        form_name='大量保有報告書（特例対象株券等）',
        doc_type_name='大量保有報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('060', '030002'): FormCodeEntry(
        ordinance_code='060',
        form_code='030002',
        form_number='第三号様式',
        form_name='変更報告書（特例対象株券等）',
        doc_type_name='大量保有報告書',
        disclosure_type='開示',
        note=None,
    ),
    ('060', '040000'): FormCodeEntry(
        ordinance_code='060',
        form_code='040000',
        form_number='第四号様式',
        form_name='基準日の届出書',
        doc_type_name='基準日の届出書',
        disclosure_type='非開示',
        note=None,
    ),
    ('060', '040001'): FormCodeEntry(
        ordinance_code='060',
        form_code='040001',
        form_number='第四号様式',
        form_name='基準日等の変更届出書',
        doc_type_name='変更の届出書',
        disclosure_type='非開示',
        note=None,
    ),
    ('060', '090001'): FormCodeEntry(
        ordinance_code='060',
        form_code='090001',
        form_number='様式なし',
        form_name='訂正報告書（大量保有報告書・変更報告書）',
        doc_type_name='訂正大量保有報告書',
        disclosure_type='開示',
        note=None,
    ),
}

FORM_CODE_RECORD_COUNT = len(_FORM_CODE_TABLE)

_warned_unknown_form_codes: set[tuple[str, str]] = set()


def get_form_code(ordinance_code: str, form_code: str) -> FormCodeEntry | None:
    """府令コードと様式コードのペアから FormCodeEntry を返す。"""
    key = (ordinance_code, form_code)
    entry = _FORM_CODE_TABLE.get(key)
    if entry is None and key not in _warned_unknown_form_codes:
        _warned_unknown_form_codes.add(key)
        warnings.warn(
            f"Unknown formCode: ordinance={ordinance_code!r}, form={form_code!r}. ",
            category=EdinetWarning,
            stacklevel=2,
        )
    return entry


def all_form_codes() -> list[FormCodeEntry]:
    """全様式コードの一覧を返す。"""
    return list(_FORM_CODE_TABLE.values())


def _reset_warning_state() -> None:
    """テスト用。"""
    _warned_unknown_form_codes.clear()
