from edinet.financial.standards.canonical_keys import CK as CK
from edinet.financial.standards.detect import DetailLevel as DetailLevel, DetectedStandard as DetectedStandard, DetectionMethod as DetectionMethod, detect_accounting_standard as detect_accounting_standard, detect_from_dei as detect_from_dei, detect_from_namespaces as detect_from_namespaces

__all__ = ['CK', 'DetectedStandard', 'DetectionMethod', 'DetailLevel', 'detect_accounting_standard', 'detect_from_dei', 'detect_from_namespaces']
